searchData={"items":[{"type":"module","title":"Statistex","doc":"Calculate all the statistics for given samples.\n\nWorks all at once with `statistics/1` or has a lot of functions that can be triggered individually.\n\nTo avoid wasting computation, function can be given values they depend on as optional keyword arguments so that these values can be used instead of recalculating them. For an example see `average/2`.\n\nMost statistics don't really make sense when there are no samples, for that reason all functions except for `sample_size/1` raise `ArgumentError` when handed an empty list.\nIt is suggested that if it's possible for your program to throw an empty list at Statistex to handle that before handing it to Staistex to take care of the \"no reasonable statistics\" path entirely separately.\n\nLimitations of ther erlang standard library apply (particularly `:math.pow/2` raises for VERY large numbers).","ref":"Statistex.html"},{"type":"function","title":"Statistex.average/2","doc":"Calculate the average.\n\nIt's.. well the average.\nWhen the given samples are empty there is no average.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#average/2"},{"type":"function","title":"Options - Statistex.average/2","doc":"If you already have these values, you can provide both `:total` and `:sample_size`. Should you provide both the provided samples are wholly ignored.","ref":"Statistex.html#average/2-options"},{"type":"function","title":"Examples - Statistex.average/2","doc":"iex> Statistex.average([5])\n    5.0\n\n    iex> Statistex.average([600, 470, 170, 430, 300])\n    394.0\n\n    iex> Statistex.average([-1, 1])\n    0.0\n\n    iex> Statistex.average([2, 3, 4], sample_size: 3)\n    3.0\n\n    iex> Statistex.average([20, 20, 20, 20, 20], total: 100, sample_size: 5)\n    20.0\n\n    iex> Statistex.average(:ignored, total: 100, sample_size: 5)\n    20.0\n\n    iex> Statistex.average([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#average/2-examples"},{"type":"type","title":"Statistex.configuration/0","doc":"The optional configuration handed to a lot of functions.\n\nKeys used are function dependent and are documented there.","ref":"Statistex.html#t:configuration/0"},{"type":"function","title":"Statistex.frequency_distribution/1","doc":"A map showing which sample occurs how often in the samples.\n\nGoes from a concrete occurence of the sample to the number of times it was observed in the samples.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#frequency_distribution/1"},{"type":"function","title":"Examples - Statistex.frequency_distribution/1","doc":"iex> Statistex.frequency_distribution([1, 2, 4.23, 7, 2, 99])\n    %{\n      2 => 2,\n      1 => 1,\n      4.23 => 1,\n      7 => 1,\n      99 => 1\n    }\n\n    iex> Statistex.frequency_distribution([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#frequency_distribution/1-examples"},{"type":"function","title":"Statistex.maximum/1","doc":"The biggest sample.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#maximum/1"},{"type":"function","title":"Examples - Statistex.maximum/1","doc":"iex> Statistex.maximum([1, 100, 24])\n    100\n\n    iex> Statistex.maximum([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#maximum/1-examples"},{"type":"function","title":"Statistex.median/2","doc":"Calculates the median of the given samples.\n\nThe median can be thought of separating the higher half from the lower half of the samples.\nWhen all samples are sorted, this is the middle value (or average of the two middle values when the number of times is even).\nMore stable than the average.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#median/2"},{"type":"function","title":"Options - Statistex.median/2","doc":"* `:percentiles` - you can pass it a map of calculated percentiles to fetch the median from (it is the 50th percentile).\nIf it doesn't include the median/50th percentile - it will still be computed.\n* `:sorted?`: indicating the samples you're passing in are already sorted. Defaults to `false`. Only set this,\nif they are truly sorted - otherwise your results will be wrong. Sorting only occurs when percentiles aren't provided.","ref":"Statistex.html#median/2-options"},{"type":"function","title":"Examples - Statistex.median/2","doc":"iex> Statistex.median([1, 3, 4, 6, 7, 8, 9])\n    6.0\n\n    iex> Statistex.median([1, 3, 4, 6, 7, 8, 9], percentiles: %{50 => 6.0})\n    6.0\n\n    iex> Statistex.median([1, 3, 4, 6, 7, 8, 9], percentiles: %{25 => 3.0})\n    6.0\n\n    iex> Statistex.median([1, 3, 4, 6, 7, 8, 9], sorted?: true)\n    6.0\n\n    iex> Statistex.median([1, 2, 3, 4, 5, 6, 8, 9])\n    4.5\n\n    iex> Statistex.median([0])\n    0.0\n\n    iex> Statistex.median([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#median/2-examples"},{"type":"function","title":"Statistex.minimum/1","doc":"The smallest sample.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#minimum/1"},{"type":"function","title":"Examples - Statistex.minimum/1","doc":"iex> Statistex.minimum([1, 100, 24])\n    1\n\n    iex> Statistex.minimum([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#minimum/1-examples"},{"type":"type","title":"Statistex.mode/0","doc":"Careful with the mode, might be multiple values, one value or nothing.😱 See `mode/1`.","ref":"Statistex.html#t:mode/0"},{"type":"function","title":"Statistex.mode/2","doc":"Calculates the mode of the given samples.\n\nMode is the sample(s) that occur the most. Often one value, but can be multiple values if they occur the same amount of times. If no value occurs at least twice, there is no mode and it hence returns `nil`.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#mode/2"},{"type":"function","title":"Options - Statistex.mode/2","doc":"If already calculated, the `:frequency_distribution` option can be provided to avoid recalulating it.","ref":"Statistex.html#mode/2-options"},{"type":"function","title":"Examples - Statistex.mode/2","doc":"iex> Statistex.mode([5, 3, 4, 5, 1, 3, 1, 3])\n    3\n\n    iex> Statistex.mode([1, 2, 3, 4, 5])\n    nil\n\n    # When a measurement failed and nils is reported as the only value\n    iex> Statistex.mode([nil])\n    nil\n\n    iex> Statistex.mode([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.\n\n    iex> mode = Statistex.mode([5, 3, 4, 5, 1, 3, 1])\n    iex> Enum.sort(mode)\n    [1, 3, 5]","ref":"Statistex.html#mode/2-examples"},{"type":"function","title":"Statistex.outlier_bounds/2","doc":"Calculates the lower and upper bound for outliers.\n\nAny sample that is `<` as the lower bound and any sample `>` are outliers of\nthe given `samples`.\n\nList passed needs to be non empty, otherwise an `ArgumentError` is raised.","ref":"Statistex.html#outlier_bounds/2"},{"type":"function","title":"Options - Statistex.outlier_bounds/2","doc":"* `:percentiles` - you can pass it a map of calculated percentiles (25th and 75th are needed).\nIf it doesn't include them - it will still be computed.\n* `:sorted?`: indicating the samples you're passing in are already sorted. Defaults to `false`. Only set this,\nif they are truly sorted - otherwise your results will be wrong. Sorting only occurs when percentiles aren't provided.","ref":"Statistex.html#outlier_bounds/2-options"},{"type":"function","title":"Examples - Statistex.outlier_bounds/2","doc":"iex> Statistex.outlier_bounds([3, 4, 5])\n    {0.0, 8.0}\n\n    iex> Statistex.outlier_bounds([4, 5, 3])\n    {0.0, 8.0}\n\n    iex> Statistex.outlier_bounds([3, 4, 5], sorted?: true)\n    {0.0, 8.0}\n\n    iex> Statistex.outlier_bounds([3, 4, 5], percentiles: %{25 => 3.0, 75 => 5.0})\n    {0.0, 8.0}\n\n    iex> Statistex.outlier_bounds([1, 2, 6, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50])\n    {22.5, 66.5}\n\n    iex> Statistex.outlier_bounds([50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 99, 99, 99])\n    {31.625, 80.625}\n\n    iex> Statistex.outlier_bounds([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#outlier_bounds/2-examples"},{"type":"function","title":"Statistex.outliers/2","doc":"Returns all outliers for the given `samples`, along with the remaining values.\n\nReturns: `{outliers, remaining_samples`} where `remaining_samples` has the outliers removed.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#outliers/2"},{"type":"function","title":"Options - Statistex.outliers/2","doc":"* `:outlier_bounds` - if you already have calculated the outlier bounds.\n* `:percentiles` - you can pass it a map of calculated percentiles (25th and 75th are needed).\nIf it doesn't include them - it will still be computed.\n* `:sorted?`: indicating the samples you're passing in are already sorted. Defaults to `false`. Only set this,\nif they are truly sorted - otherwise your results will be wrong. Sorting only occurs when percentiles aren't provided.","ref":"Statistex.html#outliers/2-options"},{"type":"function","title":"Examples - Statistex.outliers/2","doc":"iex> Statistex.outliers([3, 4, 5])\n    {[], [3, 4, 5]}\n\n    iex> Statistex.outliers([1, 2, 6, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50])\n    {[1, 2, 6], [50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50]}\n\n    iex> Statistex.outliers([50, 50, 1, 50, 50, 50, 50, 50, 2, 50, 50, 50, 50, 6])\n    {[1, 2, 6], [50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50]}\n\n    iex> Statistex.outliers([50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 99, 99, 99])\n    {[99, 99, 99], [50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50]}\n\n    iex> Statistex.outliers([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#outliers/2-examples"},{"type":"type","title":"Statistex.percentiles/0","doc":"The percentiles map returned by `percentiles/2`.","ref":"Statistex.html#t:percentiles/0"},{"type":"function","title":"Statistex.percentiles/2","doc":"See `percentiles/3`.","ref":"Statistex.html#percentiles/2"},{"type":"function","title":"Statistex.percentiles/3","doc":"Calculates the value at the `percentile_rank`-th percentile.\n\nThink of this as the value below which `percentile_rank` percent of the samples lie.\nFor example, if `Statistex.percentiles(samples, 99) == 123.45`,\n99% of samples are less than 123.45.\n\nPassing a number for `percentile_rank` calculates a single percentile.\nPassing a list of numbers calculates multiple percentiles, and returns them\nas a map like %{90 => 45.6, 99 => 78.9}, where the keys are the percentile\nnumbers, and the values are the percentile values.\n\nPercentiles must be between 0 and 100 (excluding the boundaries).\n\nThe method used for interpolation is [described here and recommended by NIST](https://www.itl.nist.gov/div898/handbook/prc/section2/prc262.htm).\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#percentiles/3"},{"type":"function","title":"Options - Statistex.percentiles/3","doc":"* `:sorted?`: indicating the samples you're passing in are already sorted. Defaults to `false`. Only set this,\nif they are truly sorted - otherwise your results will be wrong.","ref":"Statistex.html#percentiles/3-options"},{"type":"function","title":"Examples - Statistex.percentiles/3","doc":"iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 12.5)\n    %{12.5 => 1.0}\n\n    iex> Statistex.percentiles([1, 1, 3, 3, 3, 4, 5, 5], 12.5, sorted?: true)\n    %{12.5 => 1.0}\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [50])\n    %{50 => 3.0}\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [75])\n    %{75 => 4.75}\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 99)\n    %{99 => 5.0}\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [50, 75, 99])\n    %{50 => 3.0, 75 => 4.75, 99 => 5.0}\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 100)\n    ** (ArgumentError) percentile must be between 0 and 100, got: 100\n\n    iex> Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 0)\n    ** (ArgumentError) percentile must be between 0 and 100, got: 0\n\n    iex> Statistex.percentiles([], [50])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#percentiles/3-examples"},{"type":"type","title":"Statistex.sample/0","doc":"A single sample/","ref":"Statistex.html#t:sample/0"},{"type":"function","title":"Statistex.sample_size/1","doc":"Number of samples in the given list.\n\nNothing to fancy here, this just calls `length(list)` and is only provided for completeness sake.","ref":"Statistex.html#sample_size/1"},{"type":"function","title":"Examples - Statistex.sample_size/1","doc":"iex> Statistex.sample_size([])\n    0\n\n    iex> Statistex.sample_size([1, 1, 1, 1, 1])\n    5","ref":"Statistex.html#sample_size/1-examples"},{"type":"type","title":"Statistex.samples/0","doc":"The samples to compute statistics from.\n\nImportantly this list is not empty/includes at least one sample otherwise an `ArgumentError` will be raised.","ref":"Statistex.html#t:samples/0"},{"type":"function","title":"Statistex.standard_deviation/2","doc":"Calculate the standard deviation.\n\nA measurement how much samples vary (the higher the more the samples vary). It's the square root of the variance. Unlike the variance, its unit is the same as that of the sample (as calculating the variance includes squaring).","ref":"Statistex.html#standard_deviation/2"},{"type":"function","title":"Options - Statistex.standard_deviation/2","doc":"If already calculated, the `:variance` option can be provided to avoid recalulating those values.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#standard_deviation/2-options"},{"type":"function","title":"Examples - Statistex.standard_deviation/2","doc":"iex> Statistex.standard_deviation([4, 9, 11, 12, 17, 5, 8, 12, 12])\n    4.0\n\n    iex> Statistex.standard_deviation(:dontcare, variance: 16.0)\n    4.0\n\n    iex> Statistex.standard_deviation([42])\n    0.0\n\n    iex> Statistex.standard_deviation([1, 1, 1, 1, 1, 1, 1])\n    0.0\n\n    iex> Statistex.standard_deviation([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#standard_deviation/2-examples"},{"type":"function","title":"Statistex.standard_deviation_ratio/2","doc":"Calculate the standard deviation relative to the average.\n\n  This helps put the absolute standard deviation value into perspective expressing it relative to the average. It's what percentage of the absolute value of the average the variance takes.\n\n  `Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#standard_deviation_ratio/2"},{"type":"function","title":"Options - Statistex.standard_deviation_ratio/2","doc":"If already calculated, the `:average` and `:standard_deviation` options can be provided to avoid recalulating those values.\n\n  If both values are provided, the provided samples will be ignored.","ref":"Statistex.html#standard_deviation_ratio/2-options"},{"type":"function","title":"Examples - Statistex.standard_deviation_ratio/2","doc":"iex> Statistex.standard_deviation_ratio([4, 9, 11, 12, 17, 5, 8, 12, 12])\n      0.4\n\n      iex> Statistex.standard_deviation_ratio([-4, -9, -11, -12, -17, -5, -8, -12, -12])\n      0.4\n\n      iex> Statistex.standard_deviation_ratio([4, 9, 11, 12, 17, 5, 8, 12, 12], average: 10.0, standard_deviation: 4.0)\n      0.4\n\n      iex> Statistex.standard_deviation_ratio(:ignored, average: 10.0, standard_deviation: 4.0)\n      0.4\n\n      iex> Statistex.standard_deviation_ratio([])\n      ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#standard_deviation_ratio/2-examples"},{"type":"function","title":"Statistex.statistics/2","doc":"Calculate all statistics Statistex offers for a given list of numbers.\n\nThe statistics themselves are described in the individual samples that can be used to calculate individual values.\n\n`ArgumentError` is raised if the given list is empty.","ref":"Statistex.html#statistics/2"},{"type":"function","title":"Options - Statistex.statistics/2","doc":"* `:percentiles`: percentiles to calculate (see `percentiles/2`).\nThe percentiles 25th, 50th (median) and 75th are always calculated.\n* `:exclude_outliers` can be set to `true` or `false`. Defaults to `false`.\nIf this option is set to `true` the outliers are excluded from the calculation\nof the statistics.\n* `:sorted?`: indicating the samples you're passing in are already sorted. Defaults to `false`. Only set this,\nif they are truly sorted - otherwise your results will be wrong.","ref":"Statistex.html#statistics/2-options"},{"type":"function","title":"Examples - Statistex.statistics/2","doc":"iex> Statistex.statistics([50, 50, 450, 450, 450, 500, 500, 500, 600, 900])\n    %Statistex{\n      total: 4450,\n      average: 445.0,\n      variance: 61_361.11111111111,\n      standard_deviation: 247.71175004652304,\n      standard_deviation_ratio: 0.5566556180820742,\n      median: 475.0,\n      percentiles: %{25 => 350.0, 50 => 475.0, 75 => 525.0},\n      frequency_distribution: %{50 => 2, 450 => 3, 500 => 3, 600 => 1, 900 => 1},\n      mode: [500, 450],\n      minimum: 50,\n      maximum: 900,\n      lower_outlier_bound: 87.5,\n      upper_outlier_bound: 787.5,\n      outliers: [50, 50, 900],\n      sample_size: 10\n    }\n\n    # excluding outliers changes the results\n    iex> Statistex.statistics([50, 50, 450, 450, 450, 500, 500, 500, 600, 900], exclude_outliers: true)\n    %Statistex{\n      total: 3450,\n      average: 492.85714285714283,\n      variance: 2857.142857142857,\n      standard_deviation: 53.452248382484875,\n      standard_deviation_ratio: 0.1084538372977954,\n      median: 500.0,\n      percentiles: %{25 => 450.0, 50 => 500.0, 75 => 500.0},\n      frequency_distribution: %{450 => 3, 500 => 3, 600 => 1},\n      mode: [500, 450],\n      maximum: 600,\n      minimum: 450,\n      lower_outlier_bound: 87.5,\n      upper_outlier_bound: 787.5,\n      outliers: [50, 50, 900],\n      sample_size: 7\n    }\n\n    iex> Statistex.statistics([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#statistics/2-examples"},{"type":"type","title":"Statistex.t/0","doc":"All the statistics `statistics/1` computes from the samples.\n\nFor a description of what a given value means please check out the function here by the same name, it will have an explanation.","ref":"Statistex.html#t:t/0"},{"type":"function","title":"Statistex.total/1","doc":"The total of all samples added together.\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#total/1"},{"type":"function","title":"Examples - Statistex.total/1","doc":"iex> Statistex.total([1, 2, 3, 4, 5])\n    15\n\n    iex> Statistex.total([10, 10.5, 5])\n    25.5\n\n    iex> Statistex.total([-10, 5, 3, 2])\n    0\n\n    iex> Statistex.total([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#total/1-examples"},{"type":"function","title":"Statistex.variance/2","doc":"Calculate the variance.\n\nA measurement how much samples vary (the higher the more the samples vary). This is the variance of a sample and is hence in its calculation divided by sample_size - 1 (Bessel's correction).\n\n`Argumenterror` is raised if the given list is empty.","ref":"Statistex.html#variance/2"},{"type":"function","title":"Options - Statistex.variance/2","doc":"If already calculated, the `:average` and `:sample_size` options can be provided to avoid recalulating those values.","ref":"Statistex.html#variance/2-options"},{"type":"function","title":"Examples - Statistex.variance/2","doc":"iex> Statistex.variance([4, 9, 11, 12, 17, 5, 8, 12, 12])\n    16.0\n\n    iex> Statistex.variance([4, 9, 11, 12, 17, 5, 8, 12, 12], sample_size: 9, average: 10.0)\n    16.0\n\n    iex> Statistex.variance([42])\n    0.0\n\n    iex> Statistex.variance([1, 1, 1, 1, 1, 1, 1])\n    0.0\n\n    iex> Statistex.variance([])\n    ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.","ref":"Statistex.html#variance/2-examples"},{"type":"extras","title":"Statistex","doc":"# Statistex [![Hex Version](https://img.shields.io/hexpm/v/statistex.svg)](https://hex.pm/packages/statistex) [![docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/statistex/) [![CI](https://github.com/bencheeorg/statistex/actions/workflows/main.yml/badge.svg)](https://github.com/bencheeorg/statistex/actions/workflows/main.yml) [![Coverage Status](https://coveralls.io/repos/github/bencheeorg/statistex/badge.svg?branch=main)](https://coveralls.io/github/bencheeorg/statistex?branch=main)\n\nStatistex helps you do common statistics calculations and to explore a data set. It focusses on two things:\n\n* providing you a `statistics/2` function that just **computes all statistics it knows for a data set**, reusing previously made calculations to not compute something again (for instance standard deviation needs the average, so it first computes the average and then passes it on): `Statistex.statistics(samples)`\n* gives you the opportunity to **pass known values to functions** so that it doesn't need to compute more than it absolutely needs to: `Statistex.standard_deviation(samples, average: computed_average)`","ref":"readme.html"},{"type":"extras","title":"Installation - Statistex","doc":"```elixir\ndef deps do\n  [\n    {:statistex, \"~> 1.0\"}\n  ]\nend\n```\n\nSupported elixir versions are 1.6+ (together with their respective erlang OTP versions aka 19+).\nTests are only running against elixir 1.12+ though, as some dependencies aren't compatible with versions that old.\nBut also, most people probably don't care about them.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Statistex","doc":"Check out the [documentation of the main Statistex module](https://hexdocs.pm/statistex/Statistex.html) but here is a small overview:\n\n```elixir\niex> samples = [1, 3.0, 2.35, 11.0, 1.37, 35, 5.5, 10, 0, 2.35]\n# calculate all available statistics at once, efficiently reusing already calculated values\niex> Statistex.statistics(samples)\n%Statistex{\n  total: 71.57,\n  average: 7.156999999999999,\n  variance: 109.66060111111112,\n  standard_deviation: 10.471895774457991,\n  standard_deviation_ratio: 1.4631683351205802,\n  median: 2.675,\n  percentiles: %{25 => 1.2775, 50 => 2.675, 75 => 10.25},\n  frequency_distribution: %{\n    0 => 1,\n    1 => 1,\n    10 => 1,\n    35 => 1,\n    1.37 => 1,\n    2.35 => 2,\n    3.0 => 1,\n    5.5 => 1,\n    11.0 => 1\n  },\n  mode: 2.35,\n  minimum: 0,\n  maximum: 35,\n  lower_outlier_bound: -12.18125,\n  upper_outlier_bound: 23.708750000000002,\n  outliers: [35],\n  sample_size: 10\n}\n# or just calculate the value you need\niex> Statistex.average(samples)\n7.156999999999999\n# Calculate the value you want reusing values you already know\n# (check the docs for what functions accepts what options)\niex> Statistex.average(samples, sample_size: 10)\n7.156999999999999\n# Most Statistex functions raise given an empty list as most functions don't make sense then.\n# It is recommended that you manually handle the empty list case should that occur as your\n# output is likely also very different from when you have statistics.\niex> Statistex.statistics([])\n** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least one number.\n# You can exclude outliers from the calculation of statistics\niex> Statistex.statistics(samples, exclude_outliers: true)\n%Statistex{\n  total: 36.57,\n  average: 4.0633333333333335,\n  variance: 15.696975,\n  standard_deviation: 3.96194081227875,\n  standard_deviation_ratio: 0.9750469595435808,\n  median: 2.35,\n  percentiles: %{25 => 1.185, 50 => 2.35, 75 => 7.75},\n  frequency_distribution: %{\n    0 => 1,\n    1 => 1,\n    10 => 1,\n    1.37 => 1,\n    2.35 => 2,\n    3.0 => 1,\n    5.5 => 1,\n    11.0 => 1\n  },\n  mode: 2.35,\n  minimum: 0,\n  maximum: 11.0,\n  lower_outlier_bound: -12.18125,\n  upper_outlier_bound: 23.708750000000002,\n  outliers: [35],\n  sample_size: 9\n}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Supported Statistics - Statistex","doc":"For an up to date overview with explanations please check out the [documentation of the Statistex module](https://hexdocs.pm/statistex/Statistex.html).\n\nStatistics currently supported:\n\n* average\n* frequency_distribution\n* maximum\n* median\n* minimum\n* mode\n* percentiles\n* sample_size\n* standard_deviation\n* standard_deviation_ratio\n* total\n* variance\n* outliers (determining outliers)\n* outlier bounds (lower and upper bound of when samples start being considered outliers)","ref":"readme.html#supported-statistics"},{"type":"extras","title":"Alternatives - Statistex","doc":"In elixir there are 2 notable other libraries that I'm aware of: [statistics](https://github.com/msharp/elixir-statistics) and [Numerix](https://github.com/safwank/Numerix).\n\nBoth include more functions than just for statistics: general math and more (drawing of random values for instance). They also have more statistics related functions as of this writing. So if you'e looking for something, that Statistex doesn't provide (yet) these are some of the first places I'd look.\n\nWhy would you still want to use Statistex?\n\n* `statistics/2` is really nice when you're just exploring a data set or just want to have _everything_ at once\n* when calling `statistics/2` Statistex **reuses previously calculated values** (_average_ for _standard_deviation_ for instance, or a sorted list of samples for some calculations) which makes for more efficient calculations. Statistex **extends that capability to you** so that you can pass pre calculated values as optional arguments.\n* small and focussed on just statistics :)\n\nWe're naturally also looking to add more statistical functions as we go along, and pull requests are very welcome :)","ref":"readme.html#alternatives"},{"type":"extras","title":"Performance - Statistex","doc":"Statistex is written in pure elixir. C-extensions and friends would surely be faster. The goal of statistex is to be as fast possible in pure elixir while providing correct results. Hence, the focus on reusing previously calculated values and providing that ability to users.","ref":"readme.html#performance"},{"type":"extras","title":"History - Statistex","doc":"Statistex was extracted from [benchee](https://github.com/bencheeorg/benchee) and as such it powers benchees statistics calculations. Its great ancestor (if you will) was first conceived in [this commit](https://github.com/bencheeorg/benchee/commit/60fba66f927e0da20c4d16379dbf7274f77e63b5#diff-9d500e7ee9bd945a93b7172cca013d64).","ref":"readme.html#history"},{"type":"extras","title":"Contributing - Statistex","doc":"Contributions to benchee are **very welcome**! Bug reports, documentation, spelling corrections, new statistics, bugfixes... all of those (and probably more) are much appreciated contributions!\n\nPlease respect the [Code of Conduct](//github.com/bencheeorg/statistex/blob/master/CODE_OF_CONDUCT.md).\n\nYou can also look directly at the [open issues](https://github.com/bencheeorg/statistex/issues).\n\nA couple of (hopefully) helpful points:\n\n* Feel free to ask for help and guidance on an issue/PR (\"How can I implement this?\", \"How could I test this?\", ...)\n* Feel free to open early/not yet complete pull requests to get some early feedback\n* When in doubt if something is a good idea open an issue first to discuss it\n* In case I don't respond feel free to bump the issue/PR or ping me in other places","ref":"readme.html#contributing"},{"type":"extras","title":"Development - Statistex","doc":"* `mix deps.get` to install dependencies\n* `mix test` to run tests\n* `mix dialyzer` to run dialyzer for type checking, might take a while on the first invocation (try building plts first with `mix dialyzer --plt`)\n* `mix credo` to find code style problems","ref":"readme.html#development"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}